@@ -145,7 +145,8 @@ class CalibrationConstantVersion:
     # provided event_at and the CCV.begin_at
     @staticmethod
     def get_closest_by_time(cal_client,
-                            calibration_constant_ids, physical_detector_unit_id,
+                            calibration_constant_ids,
+                            physical_detector_unit_id,
                             event_at, snapshot_at):
         resp = cal_client.get_closest_calibration_constant_version_api(
             calibration_constant_ids, physical_detector_unit_id,
@@ -165,14 +166,16 @@ class CalibrationConstantVersion:
                                         detector_id,
                                         karabo_da,
                                         event_at, snapshot_at):
-        resp = cal_client.get_closest_calibration_constant_version_by_detector_api(
-            calibration_constant_id, detector_id, karabo_da,
-            event_at, snapshot_at
-        )
+        resp = \
+            cal_client.get_closest_calibration_constant_version_by_detector_api(  # noqa
+                calibration_constant_id, detector_id, karabo_da,
+                event_at, snapshot_at
+            )
 
-        Base.cal_debug(MODULE_NAME,
-                       'ccv >> get_closest_calibration_constant_version_by_detector_api',
-                       resp)
+        Base.cal_debug(
+            MODULE_NAME,
+            'ccv >> get_closest_calibration_constant_version_by_detector_api',
+            resp)
         return Base.format_response(resp, GET, HTTPStatus.OK, MODULE_NAME)
 
     # To return all constant versions
